==> gcc-g%2B%2B-4.5-20101118.tar.bz2: gcc-4.5-20101118/libstdc++-v3/testsuite/30_threads/shared_future/members/wait.cc <==
// { dg-do run { target *-*-freebsd* *-*-netbsd* *-*-linux* *-*-solaris* *-*-cygwin *-*-darwin* alpha*-*-osf* mips-sgi-irix6* } }
// { dg-options " -std=gnu++0x -pthread" { target *-*-freebsd* *-*-netbsd* *-*-linux* alpha*-*-osf* mips-sgi-irix6* } }
// { dg-options " -std=gnu++0x -pthreads" { target *-*-solaris* } }
// { dg-options " -std=gnu++0x " { target *-*-cygwin *-*-darwin* } }
// { dg-require-cstdint "" }
// { dg-require-gthreads "" }
// { dg-require-atomic-builtins "" }

// Copyright (C) 2009 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 3, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING3.  If not see
// <http://www.gnu.org/licenses/>.


#include <future>
#include <thread>
#include <mutex>
#include <testsuite_hooks.h>

void wait(std::shared_future<void> f)
{
  f.wait();
}

void test01()
{
  std::promise<void> p1;
  std::shared_future<void> f1(p1.get_future());

  std::thread t1(wait, f1);
  std::thread t2(wait, f1);
  std::thread t3(wait, f1);

  p1.set_value();
  t1.join();
  t2.join();
  t3.join();
}

int main()
{
  test01();
  return 0;
}

==> gcc-g%2B%2B-4.6-20101120.tar.bz2: gcc-4.6-20101120/libstdc++-v3/testsuite/30_threads/shared_future/members/wait.cc <==
// { dg-do run { target *-*-freebsd* *-*-netbsd* *-*-linux* *-*-solaris* *-*-cygwin *-*-darwin* alpha*-*-osf* mips-sgi-irix6* } }
// { dg-options " -std=gnu++0x -pthread" { target *-*-freebsd* *-*-netbsd* *-*-linux* alpha*-*-osf* mips-sgi-irix6* } }
// { dg-options " -std=gnu++0x -pthreads" { target *-*-solaris* } }
// { dg-options " -std=gnu++0x " { target *-*-cygwin *-*-darwin* } }
// { dg-require-cstdint "" }
// { dg-require-gthreads "" }
// { dg-require-atomic-builtins "" }

// Copyright (C) 2009 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 3, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING3.  If not see
// <http://www.gnu.org/licenses/>.


#include <future>
#include <thread>
#include <mutex>
#include <testsuite_hooks.h>

void fut_wait(std::shared_future<void> f)
{
  f.wait();
}

void test01()
{
  std::promise<void> p1;
  std::shared_future<void> f1(p1.get_future());

  std::thread t1(fut_wait, f1);
  std::thread t2(fut_wait, f1);
  std::thread t3(fut_wait, f1);

  p1.set_value();
  t1.join();
  t2.join();
  t3.join();
}

int main()
{
  test01();
  return 0;
}
